Module hadean_std::graph [] [src]

A scalable distributed graph datastructure.

Structs

Edge
EdgeIter
Graph

A scalable distributed graph datastructure. Graph<V,E> is a graph datastructure using an adjacency list representation.

GraphConstructor

Construct a Graph<V,E> from arbitrary vertex identifiers. Here's an example of building a graph from Strings:

GraphInterpreter

Interpret a Graph<V,E> using arbitrary vertex identifiers supplied to GraphConstructor. Here's an example of building a graph from Strings and interpreting it:

MessageIter